# 0.2.0 - Add scrubber concatenation

* Add scrubbers.Concat to make simple concatenation of scrubbers possible

# 0.1.4 Markdown readme

* Make our README look beautiful on PyPI

# 0.1.3 - Fix import

* fixed [import issue #1](https://github.com/RegioHelden/django-scrubber/pull/1) - Thanks to [Charlie Denton](https://github.com/meshy)

# 0.1.2 - Bumpversion support

* Use bumpversion and travis to make new releases

# 0.1.1 - Project renaming

* add pip package
* rename project: django\_scrubber → django-scrubber

# 0.1.0 - First release

* initial working release
